from OpenGL.GL import *
import gutil
import os


class Image:
    def __init__(self, texname):
        filename = os.path.join('data', texname)
        filename += ".png"

        self.texture, self.width, self.height = gutil.loadImage(filename)
        self.displayList = gutil.createTexDL(self.texture, self.width, self.height)
  

    def __del__(self):
        if self.texture != None:
            gutil.delTexture(self.texture)
            self.texture = None
        if self.displayList != None:
            gutil.delDL(self.displayList)
            self.displayList = None

    def draw(self, pos=None, width = None, height = None, color=(1,1,1,1), rotation=0, rotationCenter=None, rotMatrix=None, centered=False):
        glColor4fv(color)

        if not width:
            width = self.width
        if not height:
            height = self.height

        if centered:
            x = pos[0] - width/2 
            y = pos[1] - height/2
            pos = (x,y)

        if pos:
            glLoadIdentity()
            glTranslate(pos[0],pos[1],0)

        if rotation != 0:
            if rotationCenter == None:
                rotationCenter = (width / 2, height / 2)
            (w,h) = rotationCenter
            glTranslate(rotationCenter[0],rotationCenter[1],0)
            glRotate(rotation,0,0,-1)
            glTranslate(-rotationCenter[0],-rotationCenter[1],0)
        elif rotMatrix:
            R = rotMatrix

            rot = [R[0], R[3], R[6], 0.,
                     R[1], R[4], R[7], 0.,
                     R[2], R[5], R[8], 0.,
                     0, 0, 0, 1.0] 

            if rotationCenter == None:
                rotationCenter = (width / 2, height / 2)
            glTranslate(rotationCenter[0],rotationCenter[1],0)
            glMultMatrixf(rot)
            glTranslate(-rotationCenter[0],-rotationCenter[1],0)
        

        if width != self.width or height != self.height:
            glScalef(width/(self.width*1.0), height/(self.height*1.0), 1.0)
                

        glCallList(self.displayList)
