
from Image import Image
from ODEObject import ODEObject
from Balloon import Balloon
from Fan import Fan
from Box import Box

import ode
import math 

from constants import *
from util import *

def rot_m(theta):
    return (math.cos(theta), math.sin(theta), 0, -math.sin(theta), math.cos(theta),0,0,0,1)
    

class  JayBalloon(ODEObject):

    def __init__(self,world,space,list, pos=(-1,1)):

        self.fuel = 100
        self.maxFuel = 400
        self.burnRate = 5.5

        self.burn = False
        self.ventDir = {}
        self.ventDir['l'] = False
        self.ventDir['r'] = False
        self.ventDir['d'] = False

        x1, y1 = pos

        self.upforce = 380*STEPS_PER_FRAME
        self.dist = .2
        r = .55 # balloon radius
        q = self.dist # delta between basket and ball
        w = .2 # box width
        h = .2 # box height
        links = 1 # number or rope links
        

        self.radius = r
        self.startRadius = r

        self.flame = Image("flame")
        self.balloon = Balloon(world,space,list,pos=(0,1), radius = r, image='balloon', static_color=True)
        self.box = Box(world,space,list, pos=(0,0), size = (w, h, 1))

        self.box.image = Image('basket')
        

        #set positions
        self.balloon.body.setPosition((x1,y1,0))
        self.box.body.setPosition((x1,y1-r-q,0))
        
        #make the joints
        self.j1 = ode.FixedJoint(world)
        self.j1.attach(self.balloon.body,self.box.body)
        self.j1.setFixed()
        
        

    def draw(self):

        if self.burn and self.fuel:
            rotation = self.box.body.getRotation()
            flamepos = self.box.body.getRelPointPos((0,0.15,0))
            self.flame.draw(pos=coord(flamepos[0], flamepos[1]),width=10, height=10, rotMatrix=rotation, centered=True )

    def update(self,dt):
        if self.balloon:
            if self.burn and self.fuel > 0:
                self.inflate(dt)
                self.fuel -= dt * self.burnRate
                if self.fuel < 0:
                    self.fuel = 0

            if self.radius > .5 * self.startRadius:
                if self.ventDir['r']:
                    self.deflate(dt)
                    self.balloon.body.addForce((-10*STEPS_PER_FRAME,0,0))
                if self.ventDir['l']:
                    self.deflate(dt)
                    self.balloon.body.addForce((10*STEPS_PER_FRAME,0,0))
                if self.ventDir['d']:
                    self.deflate(dt)

            self.balloon.body.addForce((0,self.upforce,0))


    def setSize(self):
        self.balloon.width = self.radius * 2 * PIXELS_PER_METER
        self.balloon.height = self.radius * 2 * PIXELS_PER_METER
        self.balloon.geom.setRadius(self.radius)
        newPos = self.box.body.getRelPointPos((0,self.dist+self.radius,0))
        self.balloon.body.setPosition(newPos)

        self.j1.setFixed()

    def inflate(self, delta):
        self.upforce += delta*1.4*STEPS_PER_FRAME
        self.radius += .014 * delta
        self.setSize()

    def deflate(self,delta):
        self.upforce -= delta*1.4*STEPS_PER_FRAME
        self.radius -= .014 * delta
        self.setSize()

    def startBurn(self):
        self.burn = True

    def stopBurn(self):
        self.burn = False
    
    def startVent(self,dir):
        self.ventDir[dir] = True

    def stopVent(self,dir):
        self.ventDir[dir] = False
