from Image import Image
import pygame
from pygame.locals import *
import math 

from constants import *
from util import *

from Text import Text

from Balloon import Balloon


class  UI:

    def __init__(self, world, space, list, player, level):
        self.world = world
        self.space = space
        self.object_list = list
        self.junk_repository = []
        self.box = Image('blank')
        self.cursor_x, self.cursor_y = (0,0)
        self.width, junk = coord(.9,0)
        self.width = UI_WIDTH
        self.height = DISPLAY_HEIGHT
        self.color = (.2,.2,.8,1)
        self.x, self.y = (DISPLAY_WIDTH-self.width, 0)
        self.player = player
        self.restartText = Text("Restart Level",fontsize = 20 )
        self.fuelText = Text("Fuel:", fontsize = 30)
        self.flame = Image("flame")
        self.level = level

        self.titleText = Text("Epic Escape", fontsize=38, color=(200,200,240,255))

        if level.sandBox:
            instructions = ["Welcome to the sandbox:","   Click in the play area","     to spawn a ball.","   Type '[' or ']' to change","     the ball size."]
        else:
            instructions = [ "Keys:","   Up to burn.","   Left of open left vents.","   Right to open right vents.", "   Down to open main vents."]

        self.levelNum = Text("Level %d" % level.level,fontsize=45)
        self.levelText = []
        for message in level.levelText:
            self.levelText.append(Text(message,fontsize=18))

        self.instructionText = []
        for message in instructions:
            self.instructionText.append(Text(message,fontsize=14))

        #print self.x, self.y, inv_coord(self.x, self.y)
        #print self.width, self.height


    def update(self):
        pass
        
    def draw(self):
        fuelDim = (20, 200)

        self.box.draw(pos=(self.x,self.y), width=self.width,height=self.height, color=self.color)

        self.fuelText.draw(pos=(self.x+20, self.y+300-3))
        self.box.draw(pos=(self.x+120, self.y+300), width=fuelDim[0],height = fuelDim[1], color=(0,0,0,1))
        if self.player.fuel:
            self.box.draw(pos=(self.x+120, self.y+300), width=fuelDim[0], height = fuelDim[1]*1.0 * self.player.fuel/ self.player.maxFuel, color = (.3,.4,.5,1))

            if self.player.burn:
                self.flame.draw(pos=(self.x+120, self.y+300+fuelDim[1]*1.0 * self.player.fuel/ self.player.maxFuel), width = fuelDim[0], height= fuelDim[0])

        self.box.draw(pos=(self.x+20, self.y+20), width=self.width-40, height = self.restartText.height*1.5, color=(.6,.6,.6,1))
        self.restartText.draw(pos=(self.x+20+(self.width-40)/2.0, self.y+20+self.restartText.height*1.5/2.0),centered=True)
        i = 0
        for message in self.levelText:
            message.draw(pos=(self.x+20, self.y+ 200 - i*self.levelText[0].height))    
            i += 1
           
        i = 0
        for message in self.instructionText:
            message.draw(pos=(self.x+20, self.y+ 150 - i*self.instructionText[0].height))    
            i += 1

        self.levelNum.draw(pos=(self.x + self.width/2.0, 250), centered=True)

        self.titleText.draw(pos=(self.x + self.width/2.0, 570), centered=True)

        #self.cursor.draw(pos=(self.cursor_x, self.cursor_y), centered=True)
        
    def mouse_handler(self, event):
        one, two, three = pygame.mouse.get_pressed()
    
        if event.type == MOUSEBUTTONDOWN:
            #print "Mouse Down!", (self.cursor_x, self.cursor_y), (one, two, three)
            if event.button == 1:
                x,y = pygame.mouse.get_pos()
                y = DISPLAY_HEIGHT - y
                if x > self.x+20 and y > self.y+20 and x < self.x+20+(self.width-40) and y < self.y+20+self.restartText.height*1.5:
                    return 'reset'
            if self.level.sandBox:
                self.cursor_x, self.cursor_y = pygame.mouse.get_pos()
                self.cursor_y = DISPLAY_HEIGHT - self.cursor_y
                ball = Balloon(self.world,self.space, self.object_list, pos=(inv_coord(self.cursor_x,self.cursor_y)))
            
            #x1,y1,z1 = ball.body.getPosition()
            #c1,c2 = coord(x1,y1)
            #print (self.cursor_x,self.cursor_y), (c1, c2)
           
        """if event.type == MOUSEBUTTONUP:
            pass
            #print "Mouse UP!", (self.cursor_x, self.cursor_y), (one, two, three)"""
           
        return None
