#!/usr/bin/python

import gutil
import pygame
from pygame.locals import *
from OpenGL.GL import *

from Image import Image
from Text import Text
from Balloon import Balloon
from JayBalloon import JayBalloon
from Fan import Fan
from Box import Box
from constants import *
from util import *
from UI import UI
from Block import Block
from Spinner import Spinner
from Levels import Levels

import ode
import math
import os


def buildObjects():
    world = ode.World()
    world.setGravity((0,-9.81,0))
    space = ode.Space()
    floor = ode.GeomPlane(space, (0,1,0), 0.1)
    rwall = ode.GeomPlane(space, (-1,0,0), -1*inv_coord(WORLD_WIDTH,0)[0] +0.1 )
    lwall = ode.GeomPlane(space, (1,0,0), 0.1)


    return world, space


# Collision callback
def near_callback(args, geom1, geom2):
    """Callback function for the collide() method.

    This function checks if the given geoms do collide and
    creates contact joints if they do.
    """

    # Check if the objects do collide
    contacts = ode.collide(geom1, geom2)

    # Create contact joints
    world,contactgroup = args
    for c in contacts:
        c.setBounce(0.2)
        c.setMu(5000)
        j = ode.ContactJoint(world, contactgroup, c)
        j.attach(geom1.getBody(), geom2.getBody())


def main():
    pygame.init()
    pygame.mixer.init()
    gutil.initializeDisplay(DISPLAY_WIDTH, DISPLAY_HEIGHT)
    

    contactgroup = ode.JointGroup()

    levelManager = Levels()

    world, space, object_list, player = levelManager.createLevel(1)

    done = False

    ui = UI(world,space, object_list,player,levelManager)
    fps = 60.0

    box = Image('blank')


    
    clock = pygame.time.Clock()

    while not done:
        dt = clock.tick(fps)
        glClear(GL_COLOR_BUFFER_BIT)
        #box.draw(pos=(0,0), width=800, height=600, color=(0,0,0,1))

        #walls
        box.draw(pos=(0,0),width=WORLD_WIDTH,height= coord(0,0.1)[1], color=(.5,.5,.5,1))
        box.draw(pos=(0,0),width=coord(0.1,0)[0],height= WORLD_HEIGHT, color=(.5,.5,.5,1))
        box.draw(pos=(WORLD_WIDTH-coord(0.1,0)[0],0),width=coord(0.1,0)[0],height= WORLD_HEIGHT, color=(.5,.5,.5,1))
        #box.draw(pos=coord(8,0),width=100,height= 600, color=(.5,.5,.5,1))
        
        player.draw()
        for object in object_list:
            object.draw()

       
        #ball.update()
        player.update(1/fps)

        ui.draw()
        pygame.display.flip()

        for i in range(STEPS_PER_FRAME):
            space.collide((world,contactgroup), near_callback)
            world.quickStep(1/fps/STEPS_PER_FRAME)
            contactgroup.empty()

        # Don't know how often I should run this.
        for object in object_list:
            object.align()

        if player.box.body.getPosition()[1] > inv_coord(0,WORLD_HEIGHT)[1]:
            levelManager.levelUp()
            world, space, object_list, player = levelManager.createLevel()
            ui = UI(world,space, object_list,player,levelManager)

        eventlist = pygame.event.get()
        for event in eventlist:
            if event.type == QUIT \
               or event.type == KEYDOWN and event.key == K_ESCAPE:
                done = True
            if event.type == KEYDOWN and event.key == K_LEFT:
                player.startVent('l')
            if event.type == KEYDOWN and event.key == K_RIGHT:
                player.startVent('r')
            if event.type == KEYDOWN and event.key == K_UP:
                player.startBurn()
            if event.type == KEYUP and event.key == K_UP:
                player.stopBurn()
            if event.type == KEYDOWN and event.key == K_DOWN:
                player.startVent('d')
            if event.type == KEYUP and event.key == K_DOWN:
                player.stopVent('d')
            if event.type == KEYUP and event.key == K_LEFT:
                player.stopVent('l')
            if event.type == KEYUP and event.key == K_RIGHT:
                player.stopVent('r')
            if event.type == KEYDOWN and event.key == K_SPACE:
                print len(object_list)
                for o in object_list:
                    try:
                        print o, o.body.getPosition()
                    except:
                        pass
                print "player", player.balloon.body.getPosition()
            if event.type == KEYDOWN and event.key == K_p:
                """ Doesn't really work yet. """
                player.j1 = None
                object_list = filter(lambda x: x != player.balloon, object_list)
                ui = UI(world,space, object_list,player,levelManager)
                player.balloon = None
    
            if event.type == KEYDOWN and event.key == K_r:
                world, space, object_list, player = levelManager.createLevel()
                ui = UI(world,space, object_list,player,levelManager)
            if event.type == KEYDOWN and event.key == K_n:
                levelManager.levelUp()
                world, space, object_list, player = levelManager.createLevel()
                ui = UI(world,space, object_list,player,levelManager)
            if event.type == KEYDOWN and event.key == K_LEFTBRACKET and levelManager.sandBox:  #[
                for i in object_list:
                    try:
                        type = i.shape
                    except:
                        type = None
                        
                    if type == 'ball' and  i != player.balloon:
                        i.radius += .01
                        i.width = i.radius * 2 * PIXELS_PER_METER
                        i.height = i.radius * 2 * PIXELS_PER_METER
                        i.geom.setRadius(i.radius)
            if event.type == KEYDOWN and event.key == K_RIGHTBRACKET and levelManager.sandBox:  #]
                for i in object_list:
                    try:
                        type = i.shape
                    except:
                        type = None
                        
                    if type == 'ball' and  i != player.balloon:
                        i.radius -= .01
                        i.radius = max(i.radius, 0.01)
                        i.width = i.radius * 2 * PIXELS_PER_METER
                        i.height = i.radius * 2 * PIXELS_PER_METER
                        i.geom.setRadius(i.radius)
                        
                        
            if event.type == MOUSEMOTION or event.type == MOUSEBUTTONDOWN or event.type == MOUSEBUTTONUP:
                action = ui.mouse_handler(event)
                if action == 'reset':
                    world, space, object_list, player = levelManager.createLevel()
                    ui = UI(world,space, object_list,player,levelManager)
            
        

if __name__ == '__main__':
    main()
